XML Resume Library News

# XML Résumé Library News

The XML Résumé Library copyrighted, © 2000-2002 by Sean Kelly. See the copying conditions, license, and disclaimer.

This document lists user-visible changes to the library.

This document does not list all DTD changes, nor does it give complete detail on those that it does list. For a full list of changes to the DTD, please see the Element Reference in the User Guide.

## Release 1.5.1

- Added Ant support (build.xml) to examples
- Default output format for referees is now 2-column
- Fixed a bug that caused some JVM crashes while processing text output
- Improved internationalization support
- DTD fixed to support validation of XML files that use the "targets" attribute
- Small CSS improvements
- NEW: Online Resume Converter (ORC)

## Release 1.5.0

- Added support for targeted résumés. This allows the user to selectively filter out irrelevant elements and focus the résumé to a particular purpose. A demonstration of this feature is included in `example/example2.xml`
- Cascading Style Sheets (CSS) now default to being embedded directly into the HTML output, which makes it easier to email/transfer a résumé. Thanks to Luciano Cardoso for the suggestion and hint.
- Decreased the default margins to conserve space and trees (PDF output)
- Referees can now be listed in a 2-column table in the PDF and HTML output. This behavior is off by default.
- Italian, French, Spanish, and Brazilian translations have been improved/fixed. (Thanks to Didier Cassirame, Gilles Sadowski, Luciano Cardoso, and Miguel Coca)
- Localization support for the fax and phone elements has been improved. The home.word, mobile.word, and work.word params have been replaced by phone.home.phrase, phone.mobile.phrase, and phone.work.phrase (same applies to fax) that can support arbitrary orderings (eg, Mobile Phone in UK, GSM in French, Cellphone in US). Default translations for some languages may be incomplete, so please send in translations via SourceForge's Patch Request forms. (Bugs 624365, 629607)
- Makefile support (in the `examples` directory) has been added for using XMLMind's XFC package or the JFOR package to produce RTF output. This requires a separate download and is not strongly supported by the XMLRésumé Project. (Thanks to James Manning)
- The project element can now have a "title" attribute.
- The "date" element can now be used in place of "period" for the "membership" and "job" elements, and period can be used in in place of date in the award and clearance tags

## Release 1.4.2

- Fixed a bug that caused unexpected line breaks in text output (bug 566653).
- Decreased the default width of text output from 80 to 72 characters. This allows them to be transmitted in most e-mail programs without wrapping the very last part of each line.
- Added support for comma-separated formatting of degree subjects. This is now the default. (Thanks to Mark Miller.)
- Comma-formatted skill lists in text output format are now terminated with a period (feature request 575845).
- Added a new CSS stylesheet, `compact.css` that can be used to easily open an HTML résumé in Microsoft Word and save it as a DOC file. (Contributed by Mark Miller.)

## Release 1.4.1

- The output stylesheets (`us-html.xsl`, `br-a4.xsl`, etc.) are now in the `xsl/output` directory. (They were previously in the `xsl` directory.
- New elements: `<clearances>` and `<clearance>`. These elements may be used to note security clearances that you may have. (Feature request 556633.)
- New elements: `<gpa>`, `<score>` and `<possible>`. You can use these tags to include a GPA in a degree. résumé. (Feature request 560641.)
- New element: `<location>`. This element can be used to indicate the city of a `<job>`, `<degree>`, or `<membership>`. (Feature request 505444.)
- `<name>` may now contain an optional `<title>`.
- `<institution>` and `<organization>` may now contain inline elements.
- Added Dutch language support, thanks to Andre van Dijk.
- New CSS stylesheet: resume4.css.

## Release 1.4.0

- New elements: `<awards>` and `<award>`. You can use these tags to include awards or other honors in a résumé. (Feature request 548619.)
- New elements: `<interests>` and `<interest>`. You can use these tags to include your interests or hobbies in a résumé. (Feature request 504269.)
- New elements: `<fax>`, `<pager>`, and `<instantMessage>` (feature requests 485930 and 522200).
- New element: `<minor>` (feature request 558871).
- New element: `<lastModified>` (feature request 460165).
- Deprecated elements: `<skillareas>`, `<skills>`, and `<pubDate>`.
- `<phone>` (as well as the new `<fax>` element) now has a `location` attribute (feature request 448039).
- `<skill>` now has a `level` attribute (feature request 485930).
- `<degree>` may now contain multiple `<major>`s (feature request 558871).
- `<contact>` may now contain any number of elements, in any order (feature request 448039).
- `<pub>` may now contain a `<url>` (feature request 548584).
- `<degree>` may now optionally contain either a `<date>` or a `<period>` (feature requests 485930 and 460156).
- `<referee>` may now contain an optional `<title>` and an optional `<organization>` (feature request 539028).
- Added Portuguese language support, thanks to Felipe Leme.
- Added German language support, thanks to Jochen Hein (feature request 522570).
- References may now be replaced by alternate text in formatted output with the `referees.display` parameter.
- A new CSS stylesheet is included: `resume3.css`
- Fixed bug 547663: only the last skill in a list of skills was formatted when the `skills.format` parameter was set to `comma`.
- New chapter in the user guide: Converting an XML Résumé to Other Formats

## Release 1.3.3

- User guide now included!
- Namespaces are supported and used within the stylesheets.
- We're now compatible with the XSL-FO standard and FOP version 0.20.3.
- New `<link>` element to support hyperlinks to employers.

## Release 1.3.2

Bug fix release:

- Fixed bug 509432: formatting of academic degrees exhibited bizarre punctuation and spacing depending on what combination of date, institution, subjects, and annotation were present. It's clean now for all combinations.
- Fixed bug 513515: space for the subject name in an academic degree is significantly wider now.

## Release 1.3.1

This release fixes a minor bug in the catalog file for the DTD. It also puts descriptions in the HTML output into a `<div>` block with the CSS class description, enabling you to format descriptions of jobs specially.

## Release 1.3.0

- Schema Change! The `<subject>` element under a `<degree>` in order to list your college major is now a `<major>` element. You will need to change your résumés and/or software.

  As a convenience, we have provided an XSLT transformation in `xsl/124-130.xsl` that will turn version 1.2.4 résumés into 1.3.0 with the `<major>` element.

- The `<name>` under a `<copyright>` is now optional. If omitted, the name will be taken from the `<header>`.
- You can specify whether HTML and plain text headings should be standard (flush left) or centered with the `header.format` parameter.
- You can format skill sections as bullet lists or comma-separated lists with the `skills.format` parameter.
- We've simplified international addresses using a setting for the `address.format` parameter and also by allowing freeform addresses.
- You can now list and format professional memberships on your résumé with the `<memberships>` element.
- You can list subjects and levels achieved under each degree with the `<subjects>` element. Subjects are formatted for print and web, but not yet for text.
- You can list personal references with the `<referees>` element.
- Many elements contain unique `id` attributes now. You can use the `name` attribute in an `<author>` element to refer to a publication author by `id`.
- You can list projects at a job with the new `<projects>` element.
- The graduation `<date>` on a degree is optional now.
- There's an SGML catalog file now.
- The new XSL paramater `half.space` is used for a smaller amount of space between certain types of paragraphs.
- The plain text formatting cleans up extra newlines when certain parts of the resume or the titles are empty. It also wraps long lists of items cleanly.

Additionally, we've fixed some bugs in the XSL files.

## Release 1.2.4

Bugs fixed:

- Old style US addresses in HTML were coming out "City,State". Now there's a space after the comma: "City, State".
- The `<dayOfMonth>` was missing a content model; it has one now (PCDATA).
- `<fullDate>` wasn't referenced anywhere. It's gone.
- The plain text stylesheet `text.xsl` contained an invalid template that Xalan allowed but 4Suite correctly disallowed. That's fixed now.
- The HTML output explicitly sets the character set to UTF-8.
- Bullet lists in the text formatting have been greatly improved.
- No more blank labels for telephone or email when there's no telephone or email specified.
- The homepage URL now appears in the HTML formatting.

New features:

- Each job in the employment history may now contain a list of achievements, which become formatted as a bullet-list.
- Achievements and skills now use the same markup model as plain paragraphs, enabling richer semantics.
- Real en-dashes appear in periods of employment in the FO rendering.
- Hyphens in the FO rendering separating employer, job title, and period of employment use bullets now (those hyphens looked funny).
- HTML output now includes Cascading Stylesheet (CSS) "class" attributes, enabling you to customize the HTML appearance of your résumé. Two sample stylesheets, `resume1.css` and `resume2.css` are in the `css` directory.

## Release 1.2.3

- Internationalization support. The DTD and the stylesheets support formatting international addresses with a rich set of metadata. See the `example2.xml` résumé for an example. Older résumés using the US address schema are still compatible. Note that FOP 0.19.0 does not handle line breaks in addresses correctly yet. Use XEP from RenderX until the Apache XML Project can fix this bug!
- Localization support. We've replaced hard-coded words like "Professional Objective" and "résumé" as well as paper sizes and margins with configurable parameters. Driver files set these parameters and format résumés appropriately. Support for US English, UK English, and French are included.
- Date of birth. The DTD supports a `<birth>` element to record date of birth. This element is currently not formatted.

## Release 1.2.2

This release lets you specify rich content for publications in addition to free-form paragraphs, including `<artTitle>`, `<bookTitle>`, `<author>`, `<pubDate>`, `<publisher>`, and `<pageNums>`. The stylesheets will format these elements appropriately.

## Release 1.2.1

- Now compatible with FOP 1.19.0. You can still expect to see warning messages from FOP, but these are harmless.
- Acute accents now appear in the word "résumé" in the running footer in the FO output.

## Release 1.2.0

The news document is new in this release, 1.2.0.